# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.20.1~0e2ea82',
    built_at='2025-07-23 08:04:38Z',
    sha='0e2ea82aa69b9aae205f7715cf9606bbf75f9f20',
    branch='HEAD',
    tag='v4.20.1',
)
